Event

Struct Event 

pub struct Event { /* private fields */ }
Custom events that can be queried from Tendermint using a websocket client

Implementations

Source

impl Event

pub fn new(event_type: EventType, level: EventLevel) -> Event

Create a new event with no attributes and the given parameters.

pub fn level(&self) -> &EventLevel

Return the level of the event.

pub fn kind(&self) -> &EventType

Return the type of the event.

pub fn attributes(&self) -> &BTreeMap<String, String>

👎Deprecated: Accessing the event attributes directly is deprecated. Consider using domain types to compose events with attributes.

Return a reference to the event’s attributes.

pub fn attributes_mut(&mut self) -> &mut BTreeMap<String, String>

👎Deprecated: Accessing the event attributes directly is deprecated. Consider using domain types to compose events with attributes.

Return a mutable reference to the event’s attributes.

pub fn into_attributes(self) -> BTreeMap<String, String>

Return the attributes of the event, destroying it in the process.

pub fn has_subset_of_attrs<A>(&self, attrs: &A) -> bool
where A: AttributesMap,

Check if this Event has a subset of the keys and values in attrs.

pub fn delete_attribute<DATA>(&mut self)

Delete the given attribute.

pub fn raw_read_attribute<'value, DATA>(&self) -> Option<&str>
where DATA: RawReadFromEventAttributes<'value>,

Get the raw string value corresponding to a given attribute, if it exists.

pub fn read_attribute<'value, DATA>( &self, ) -> Result<<DATA as ReadFromEventAttributes<'value>>::Value, EventError>
where DATA: ReadFromEventAttributes<'value>,

Get the value corresponding to a given attribute.

pub fn read_attribute_opt<'value, DATA>( &self, ) -> Result<Option<<DATA as ReadFromEventAttributes<'value>>::Value>, EventError>
where DATA: ReadFromEventAttributes<'value>,

Get the value corresponding to a given attribute, if it exists.

pub fn has_attribute<'value, DATA>(&self) -> bool
where DATA: RawReadFromEventAttributes<'value>,

Check if a certain attribute is present in the event.

pub fn extend<DATA>(&mut self, data: DATA) -> &mut Event
where DATA: ExtendEvent,

Extend this Event with additional data.

pub fn emission_gas_cost(&self, cost_per_byte: u64) -> Option<u64>

Compute the gas cost of emitting this event. Returns None on u64 overflow.

pub fn merge(&mut self, other: Event)

Joins the attribute sets of two Event