Transaction environment contains functions that can be called from inside a tx.
Modules
- storage
- Storage types
Structs
- Event
- Custom events that can be queried from Tendermint using a websocket client
- Event
Type - ABCI event type.
- Masp
Transaction - A MASP transaction.
Enums
- Address
- An account’s address
Traits
- Borsh
Deserialize - A data-structure that can be de-serialized from binary format by NBOR.
- Borsh
Serialize - A data-structure that can be serialized into binary format by NBOR.
- Borsh
Serialize Ext - Extensions to types implementing
BorshSerialize. - Event
ToEmit - An event to be emitted in Namada.
- Result
Ext - Result extension to easily wrap custom errors into
Error. - Storage
Read - Common storage read interface
- Storage
Write - Common storage write interface
- TxEnv
- Transaction host functions
Type Aliases
- Result
- Result of a storage API call.