pub struct Event { /* private fields */ }Expand description
Custom events that can be queried from Tendermint using a websocket client
Implementations
Sourceimpl Event
impl Event
Sourcepub fn new(event_type: EventType, level: EventLevel) -> Event
pub fn new(event_type: EventType, level: EventLevel) -> Event
Create a new event with no attributes and the given parameters.
Sourcepub fn level(&self) -> &EventLevel
pub fn level(&self) -> &EventLevel
Return the level of the event.
Sourcepub fn attributes(&self) -> &BTreeMap<String, String>
👎Deprecated: Accessing the event attributes directly is deprecated. Consider using domain types to compose events with attributes.
pub fn attributes(&self) -> &BTreeMap<String, String>
Return a reference to the event’s attributes.
Sourcepub fn attributes_mut(&mut self) -> &mut BTreeMap<String, String>
👎Deprecated: Accessing the event attributes directly is deprecated. Consider using domain types to compose events with attributes.
pub fn attributes_mut(&mut self) -> &mut BTreeMap<String, String>
Return a mutable reference to the event’s attributes.
Sourcepub fn into_attributes(self) -> BTreeMap<String, String>
pub fn into_attributes(self) -> BTreeMap<String, String>
Return the attributes of the event, destroying it in the process.
Sourcepub fn has_subset_of_attrs<A>(&self, attrs: &A) -> boolwhere
A: AttributesMap,
pub fn has_subset_of_attrs<A>(&self, attrs: &A) -> boolwhere
A: AttributesMap,
Check if this Event has a subset of the keys and values
in attrs.
Sourcepub fn delete_attribute<DATA>(&mut self)where
DATA: DeleteFromEventAttributes,
pub fn delete_attribute<DATA>(&mut self)where
DATA: DeleteFromEventAttributes,
Delete the given attribute.
Sourcepub fn raw_read_attribute<'value, DATA>(&self) -> Option<&str>where
DATA: RawReadFromEventAttributes<'value>,
pub fn raw_read_attribute<'value, DATA>(&self) -> Option<&str>where
DATA: RawReadFromEventAttributes<'value>,
Get the raw string value corresponding to a given attribute, if it exists.
Sourcepub fn read_attribute<'value, DATA>(
&self,
) -> Result<<DATA as ReadFromEventAttributes<'value>>::Value, EventError>where
DATA: ReadFromEventAttributes<'value>,
pub fn read_attribute<'value, DATA>(
&self,
) -> Result<<DATA as ReadFromEventAttributes<'value>>::Value, EventError>where
DATA: ReadFromEventAttributes<'value>,
Get the value corresponding to a given attribute.
Sourcepub fn read_attribute_opt<'value, DATA>(
&self,
) -> Result<Option<<DATA as ReadFromEventAttributes<'value>>::Value>, EventError>where
DATA: ReadFromEventAttributes<'value>,
pub fn read_attribute_opt<'value, DATA>(
&self,
) -> Result<Option<<DATA as ReadFromEventAttributes<'value>>::Value>, EventError>where
DATA: ReadFromEventAttributes<'value>,
Get the value corresponding to a given attribute, if it exists.
Sourcepub fn has_attribute<'value, DATA>(&self) -> boolwhere
DATA: RawReadFromEventAttributes<'value>,
pub fn has_attribute<'value, DATA>(&self) -> boolwhere
DATA: RawReadFromEventAttributes<'value>,
Check if a certain attribute is present in the event.
Sourcepub fn extend<DATA>(&mut self, data: DATA) -> &mut Eventwhere
DATA: ExtendEvent,
pub fn extend<DATA>(&mut self, data: DATA) -> &mut Eventwhere
DATA: ExtendEvent,
Extend this Event with additional data.
Sourcepub fn emission_gas_cost(&self, cost_per_byte: u64) -> Option<u64>
pub fn emission_gas_cost(&self, cost_per_byte: u64) -> Option<u64>
Compute the gas cost of emitting this event. Returns None on u64
overflow.